﻿using System;
using System.Text;
using System.Collections.Generic;
using System.Linq;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using System.Runtime.Serialization;

namespace Tests
{
    [Serializable()]
    public class CubeRow : ISerializable
    {
        // A CubeRow may have one of the data structures below populated.

        // Either a Dictonary of concatenated column dimension captions and CubeTupe objects
        private Dictionary<string, CubeTuple> cubeTupleDict = new Dictionary<string, CubeTuple>();
        // Or a Dictonary of additional row dimension captions and CubeRow objects
        private Dictionary<string, CubeRow> cubeDict;

        public CubeRow() { }

        public CubeRow(SerializationInfo info, StreamingContext context)
        {
            this.cubeTupleDict = (Dictionary<string, CubeTuple>)info.GetValue("CubeTupleList",typeof(Dictionary<string, CubeTuple>));
            this.cubeDict = (Dictionary<string, CubeRow>)info.GetValue("CubeDict", typeof(Dictionary<string, CubeRow>));
        }

        public void setCubeDict(Dictionary<string, CubeRow> cubeDict)
        {
            this.cubeDict = cubeDict;
        }

        // Add a concatenated list column dimension caption and the MDX query result value to the CubeTuple Dictionary
        public void AddTuple(string columnName, Object columnValue)
        {
            cubeTupleDict.Add(columnName, new CubeTuple(columnName, columnValue));
        }

        public Dictionary<string, CubeRow> GetCubeDict()
        {
            return cubeDict;
        }

        public int GetCubeTupleSize() { return cubeTupleDict.Count; }

        // Return a CubeTuple object from the CubeTupe Dictionary if it exists given the dimension column name.
        public CubeTuple GetCubeTuple(string columnName)
        {
            if (!cubeTupleDict.ContainsKey(columnName))
                return null;
            else
                return cubeTupleDict[columnName];
        }

        #region ISerializable Members

        public void GetObjectData(SerializationInfo info, StreamingContext context)
        {
            info.AddValue("CubeTupleList", cubeTupleDict);
            info.AddValue("CubeDict", cubeDict);
        }

        #endregion

        // Removes a CubeTuple from the CubeTuple Dictionary        
        public void RemoveCubeTuple(string columnName)
        {
            cubeTupleDict.Remove(columnName);
        }
    }
}
